@@ -6,7 +6,7 @@ from subprocess import Popen, PIPE
 from sys import platform
 
 
-__version__ = "0.1.3"
+__version__ = "0.1.4"
 
 gunicorns = {} # gunicorn master process names/pids.
 selected_pid = None # Process ID of currently selected gunicorn master process.
@@ -94,7 +94,8 @@ def update_gunicorns():
     # Determine ports if any are missing.
     if not any([g for g in gunicorns.values() if g["port"] is None]):
         return
-    netstat = Popen(["netstat","-lp"], stdout=PIPE, stderr=PIPE).communicate()[0].split("\n")
+    netstat = Popen(["netstat","-lpn"], stdout=PIPE, 
+        stderr=PIPE).communicate()[0].split("\n")
     addr_pos = None
     pid_pos = None
     addr_heading = "Local Address"
